function Memberships = GetFuzzyMemberships(Samples, Centers, NormType, Blending)
// berechnet die Mitgliedschaftswerte von Vektoren in Clustern.
//
// Calling Sequence
//   [Memberships] = GetFuzzyMemberships(Samples, Centers, NormType, Blending)
//
// Parameters
// Samples: Matrix, die Beispielvektoren als Zeilen enthält
// Centers: Matrix, die Clusterzentren als Zeilen enthält
// NormType: Norm der Vektoren, ist Skalar größer als null, kann %inf sein
// Blending: Exponent, der auf die Mitgliedschaftswerte angewandt wird. Dieser Parameter ist optional. Voreingestellt ist zwei.
// Memberships: Mitgliedschaftswerte der Vektoren (Zeilen) in Clustern (Spalten)
//
// Description
// Diese Funktion berechnet die Mitgliedschaftswerte von Vektoren in Clustern.
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(1 : 5, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 2);
//  [Centers Memberships] = FuzzyCMeans(Samples, InitialCenters, 2, 'iterations', 10);
//  Centers
//  Memberships
//
// See also
//  SelectRandomly
//  FuzzyQuantizationError
//  FuzzyCMeans
//  GetXieBeniIndex
//
// Authors
//  Dr. Eng. (J) Harald Galda;
//
// Bibliography
// Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// start of coding after on empty line to mark the end of the head_comments section
// This file is for *xml file generation only.
endfunction
