function XieBeniIndex = GetXieBeniIndex(Samples, Centers, Memberships, NormType)
// berechnet den Xie-Beni-Index.
//
// Calling Sequence
//   [XieBeniIndex] = GetXieBeniIndex(Samples, Centers, Memberships, NormType)
//
// Parameters
// Samples: Matrix, die Beispielvektoren als Zeilen enthält
// Centers: Matrix, die Clusterzentren als Zeilen enthält
// Memberships: Matrix der Mitgliedschaftswerte, Zeilen entsprechen Beispielvektoren, Spalten entsprechen Clusterzentren
// NormType: Norm der Vektoren, ist Skalar größer als null, kann %inf sein
//
// Description
// Diese Funktion bewertet das Ergebnis von Fuzzy-Clustering mit dem Xie-Beni-Index.
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 5);
//  for k = 2 : 5
//   [Centers Memberships] = FuzzyCMeans(Samples, InitialCenters, 2, 'iterations', 10);
//   XieBeniIndex = GetXieBeniIndex(Samples, Centers(1 : k, :), Memberships(:, 1 : k), 2)
//  end;
//
// See also
//  SelectRandomly
//  FuzzyQuantizationError
//  GetFuzzyMemberships
//  FuzzyCMeans
//
// Authors
//  Dr. Eng. (J) Harald Galda;
//
// Bibliography
// Xie, X. L., and Beni, G. 'A Validity Measure for Fuzzy Clustering', IEEE Trans. Pattern Analysis and Machine Intelligence, vol. 13, pp. 841-847, (1991)

// start of coding after on empty line to mark the end of the head_comments section
// Diese Datei ist nur dazu da, damit XML-Dateien generiert werden.
endfunction
