function SOMWeights = InitSOM(Samples, GridSize, GridType)
// initialisiert die Gewichtsvektoren einer selbstorganisierenden Merkmalskarte (engl. 'self organizing map', SOM) mit einem regulären Gitter.
//
// Calling Sequence
//   [SOMWeights] = InitSOM(Samples, GridSize, GridType)
//
// Parameters
// Samples: Matrix, die Beispielvektoren als Zeilen enthält 
// GridSize: Vektor oder Skalar, gibt die Anzahl der Neuronen pro Dimension an. Alle Elemente müssen größer als eins sein.
// GridType: String, kann 'equidistant' oder 'adjusted' sein.
// SOMWeight: Matrix, die Gewichtsvektoren als Zeilen enthält.
//
// Description
// Diese Funktion initialisiert die Gewichtsvektoren einer selbstorganisierenden
// Merkmalskarte (engl. 'self organizing map', SOM) mit einem regulären Gitter. 
// Das Zentrum des Gitters ist der Mittelwert der Beispielvektoren. Das Gitter
// ist entland der Hauptkomponenten der Beispielvektoren angeordnet. Das Gitter
// kann äquidistant sein (wie in [1] vorgeschlagen) oder an die Verteilung der
// Beispielvektoren in den Richtungen der Achsen angepasst sein (wie in [2]
// beschrieben).
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  SOMWeights = InitSOM(Samples, [5 3], 'equidistant')
//
// See also
//  SelectRandomly
//
// Authors
//  Dr. Eng. (J) Harald Galda ; 
//
// Bibliography
//   [1] T. Kohonen, 'Self-organizing maps', Springer Verlag, Berlin, 2001
//   [2] Harald Galda, 'Development of a segmentation method for dermoscopic images based on color clustering', Kobe University, August 2003

// start of coding after on empty line to mark the end of the head_comments section
// This file is for XML file generation only.
endfunction
