function SOMWeights = TrainSOM(Samples, InitialWeights, GridSize, LearningRate, LearningRateParameter, Neighborhood, NeighborhoodParameter, NormType)
// trainiert eine selbstorganisierende Merkmalskarte (engl. 'self organizing map', SOM).
//
// Calling Sequence
//   [SOMWeights] = TrainSOM(Samples, InitialWeights, GridSize, LearningRate, LearningRateParameter, Neighborhood, NeighborhoodParameter, NormType)
//
// Parameters
// Samples: Matrix, die Trainingsvektoren als Zeilen enthält
// InitialWeights: Matrix, die anfängliche Gewichtsvektoren als Zeilen enthält
// GridSize: Vektor oder Skalar, gibt die Anzahl der Neuronen pro Dimension an. Alle Elemente müssen größer als eins sein.
// LearningRate: Lernrate, Funktion des Zeitschrittes und eines weiteren Parameters
// LearningRateParameter: zweiter Parameter von LearningRate(), Typ beliebig
// Neighborhood: Nachbarschaft, Funktion der Distanz, des Zeitschrittes und eines weiteren Parameters
// NeighborhoodParameter: Dritter Parameter von Neighborhood(), Typ beliebig
// NormType: Norm der Vektoren, ist Skalar größer als null, kann %inf sein
// SOMWeights: Matrix, die resultierende Gewichtsvektoren als Zeilen enthält
//
// Description
// Diese Funktion trainiert eine selbstorganisierende Merkmalskarte (engl.
// 'self organizing map', SOM)
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  GridSize = [5 3];
//  InitialWeights = InitSOM(Samples, GridSize, 'equidistant');
//  LearningRateStruct = struct('Max', 0.2, 'Min', 0.02, 'Duration', size(Samples, 1));
//  function [Result] = LinearLearningRate(TimeStep, Parameter)
//  Result = Parameter.Max - (Parameter.Max - Parameter.Min) * (TimeStep - 1) / (Parameter.Duration - 1);  
//  endfunction
//  NeighborhoodStruct = struct('Max', 5, 'Duration', size(Samples, 1));
//  function [Result] = CircularNeighborhood(Distance, TimeStep, Parameter)
//  MaxDistance = Parameter.Max - (Parameter.Max - 1) * (TimeStep - 1) / (Parameter.Duration - 1);
//  Result = double(Distance <= MaxDistance); 
//  endfunction
//  SOMWeights = TrainSOM(Samples, ...
//                        InitialWeights, ...
//                        GridSize, ...
//                        LinearLearningRate, ...
//                        LearningRateStruct, ...
//                        CircularNeighborhood, ....
//                        NeighborhoodStruct, ...
//                        2)
//
// See also
//  SelectRandomly
//  InitSOM
//
// Authors
// Dr. Eng. (J) Harald Galda ;
//
// Bibliography
//   T. Kohonen, 'Self-organizing maps', Springer Verlag, Berlin, 2001

// start of coding after on empty line to mark the end of the head_comments section
// This file is for XML file generation only.
endfunction
