function Memberships = GetFuzzyMemberships(Samples, Centers, NormType, Blending)
// calculates the membership values of vectors in fuzzy clusters.
//
// Calling Sequence
//   [Memberships] = GetFuzzyMemberships(Samples, Centers, NormType, Blending)
//
// Parameters
// Samples: matrix, contains sample vectors as rows
// Centers: matrix, contains cluster centers as rows
// NormType: norm of vectors, must be a scalar greater than zeros, can be %inf
// Blending: exponent applied to memberships. This parameter is optional. The default value is two.
// Memberships: membership values of the samples (rows) in the clusters (columns)
//
// Description
// This function calculates the membership values of vectors in fuzzy clusters.
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(1 : 5, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 2);
//  [Centers Memberships] = FuzzyCMeans(Samples, InitialCenters, 2, 'iterations', 10);
//  Centers
//  Memberships
//
// See also
//  SelectRandomly
//  FuzzyQuantizationError
//  FuzzyCMeans
//  GetXieBeniIndex
//
// Authors
//  Dr. Eng. (J) Harald Galda;
//
// Bibliography
// Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// start of coding after on empty line to mark the end of the head_comments section
// This file is for *xml file generation only.
endfunction
