function XieBeniIndex = GetXieBeniIndex(Samples, Centers, Memberships, NormType)
// calculates the Xie-Beni index.
//
// Calling Sequence
//   [XieBeniIndex] = GetXieBeniIndex(Samples, Centers, Memberships, NormType)
//
// Parameters
// Samples: matrix that includes sample vectors as rows
// Centers: matrix that includes cluster centers as rows
// Memberships: matrix of membership values, rows correspond to samples, columns correspond to clusters
// NormType: norm of vectors, must be a scalar greater than zeros, can be %inf
//
// Description
// This function evaluates a result of fuzzy clustering by the Xie-Beni index.
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 5);
//  for k = 2 : 5
//   [Centers Memberships] = FuzzyCMeans(Samples, InitialCenters, 2, 'iterations', 10);
//   XieBeniIndex = GetXieBeniIndex(Samples, Centers(1 : k, :), Memberships(:, 1 : k), 2)
//  end;
//
// See also
//  SelectRandomly
//  FuzzyQuantizationError
//  GetFuzzyMemberships
//  FuzzyCMeans
//
// Authors
//  Dr. Eng. (J) Harald Galda;
//
// Bibliography
// Xie, X. L., and Beni, G. 'A Validity Measure for Fuzzy Clustering', IEEE Trans. Pattern Analysis and Machine Intelligence, vol. 13, pp. 841-847, (1991)

// start of coding after on empty line to mark the end of the head_comments section
// This file is for *xml file generation only.
endfunction
