function SOMWeights = InitSOM(Samples, GridSize, GridType)
// initializes the weight vectors of a self organizing map (SOM) with a regular grid.
//
// Calling Sequence
//   [SOMWeights] = InitSOM(Samples, GridSize, GridType)
//
// Parameters
// Samples: matrix that includes sample vectors as rows
// GridSize: vector or scalar, specifies the number of neurons per SOM dimension. All elements must be greater than one. 
// GridType: string, can be 'equidistant' or 'adjusted', is not case sensitive
// SOMWeight: matrix that includes weight vectors as rows
//
// Description
// This function initializes the weight vectors of a self organizing map with a
// regular grid. This grid is centered at the mean vector of the samples and
// aligned according to the principal components. The grid can be equidistant 
// [1] or adjusted to the density of samples in the axis directions [2].
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  SOMWeights = InitSOM(Samples, [5 3], 'equidistant')
//
// See also
//  SelectRandomly
//  TrainSOM
//
// Authors
//  Dr. Eng. (J) Harald Galda ; 
//
// Bibliography
//   [1] T. Kohonen, 'Self-organizing maps', Springer Verlag, Berlin, 2001
//   [2] Harald Galda, 'Development of a segmentation method for dermoscopic images based on color clustering', Kobe University, August 2003

// start of coding after on empty line to mark the end of the head_comments section
// This file is for XML file generation only.
endfunction
