function Memberships = GetFuzzyMemberships(Samples, Centers, NormType, Blending)
// はクラスタにおける所属度を計算する
//
// Calling Sequence
//   [Memberships] = GetFuzzyMemberships(Samples, Centers, NormType, Blending)
//
// Parameters
// Samples:サンプルを含む行列で、サンプルは行である
// Centers:中央点を含む行列で、中央点は行である
// NormType:ベクトルにおけるノルムで、ゼロを超える数で、無限（%inf）である可能性がある
// Blending:所属度に適用される条である。このパラメータはオプショナルで、設定される値は2つである。
// Memberships:所属度を含む行列で、行はベクトルに相当して、クラスタは列に相当する
//
// Description
// 本関数はクラスタにおける所属度を計算する。
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(1 : 5, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 2);
//  [Centers Memberships] = FuzzyCMeans(Samples, InitialCenters, 2, 'iterations', 10);
//  Centers
//  Memberships
//
// See also
//  SelectRandomly
//  FuzzyQuantizationError
//  FuzzyCMeans
//  GetXieBeniIndex
//
// Authors
//  画留田ハラルド;
//
// Bibliography
// Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// start of coding after on empty line to mark the end of the head_comments section
// This file is for *xml file generation only.
endfunction
