function XieBeniIndex = GetXieBeniIndex(Samples, Centers, Memberships, NormType)
// はXie-Beniインデクスを計算する
//
// Calling Sequence
//   [XieBeniIndex] = GetXieBeniIndex(Samples, Centers, Memberships, NormType)
//
// Parameters
// Samples:サンプルを含む行列で、サンプルは行である
// Centers:中央点を含む行列で、中央点は行である
// Memberships:所属度を含む行列で、行はサンプルに相当して、列はクラスタに相当する
// NormType:ベクトルにおけるノルムで、ゼロを超える数で、無限（%inf）である可能性がある
//
// Description
// 本関数はXie-Beniインデクスを計算して、ファジークラスタリングの結果を判断する
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 5);
//  for k = 2 : 5
//   [Centers Memberships] = FuzzyCMeans(Samples, InitialCenters, 2, 'iterations', 10);
//   XieBeniIndex = GetXieBeniIndex(Samples, Centers(1 : k, :), Memberships(:, 1 : k), 2)
//  end;
//
// See also
//  SelectRandomly
//  FuzzyQuantizationError
//  GetFuzzyMemberships
//  FuzzyCMeans
//
// Authors
// 画留田ハラルド ;
//
// Bibliography
// Xie, X. L., and Beni, G. 'A Validity Measure for Fuzzy Clustering', IEEE Trans. Pattern Analysis and Machine Intelligence, vol. 13, pp. 841-847, (1991)

// start of coding after on empty line to mark the end of the head_comments section
// This file is for *xml file generation only.
endfunction
