﻿function SOMWeights = InitSOM(Samples, GridSize, GridType)
// は自己組織化マップ(英語で「self organizing map」と呼ばれて、略は「SOM」だ)のウェイトを規則的なグリッドで初期化する
//
// Calling Sequence
//   [SOMWeights] = InitSOM(Samples, GridSize, GridType)
//
// Parameters
// Samples:サンプルを含む行列で、サンプルは行である
// GridSize:各次元におけるニューロンの数を表すベクトル又はスカラーである。構成要素が1つを超える必要はある
// GridType:文字列で、可能のある値は「equidistant」又は「adjusted」である
// SOMWeight:ウェイトを含む行列で、ウェイトは行である
//
// Description
// 本関数は自己組織化マップのウェイトを規則的なグリッドで初期化する。グリッドの中央点はサンプルの平均値で、
// 軸は基本構成要素に相当する。グリッドは等距離である可能性があ [1]。従って、サンプルの軸の方向における分
// 配に合せられることができる [2]。
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  SOMWeights = InitSOM(Samples, [5 3], 'equidistant')
//
// See also
//  SelectRandomly
//
// Authors
//  画留田ハラルド ; 
//
// Bibliography
//   [1] T. Kohonen, 'Self-organizing maps', Springer Verlag, Berlin, 2001
//   [2] Harald Galda, 'Development of a segmentation method for dermoscopic images based on color clustering', Kobe University, August 2003

// start of coding after on empty line to mark the end of the head_comments section
// This file is for XML file generation only.
endfunction
