function [Centers, Memberships] = FuzzyCMeans(Samples, InitialCenters, NormType, Criterion, Value, Blending)
// führt Fuzzy-C-Means-Clustering durch.
//
// Calling Sequence
//   [Centers, Memberships] = FuzzyCMeans(Samples, InitialCenters, NormType, Criterion, Value, Blending)
//   [Centers, Memberships] = FuzzyCMeans(Samples, InitialCenters, NormType, Criterion, Value)
//   [Centers] = FuzzyCMeans(Samples, InitialCenters, NormType, Criterion, Value, Blending)
//   [Centers, Memberships] = FuzzyCMeans(Samples, InitialCenters, NormType, Criterion, Value)
//
// Parameters
// Samples: Matrix, die Beispielvektoren als Zeilen enthält
// InitialCenters: Matrix, die die anfänglichen Clusterzentren als Zeilen enthält
// NormType: Norm der Vektoren, ist Skalar größer als null, kann %inf sein
// Criterion: Art der Abbruchbedingung, kann 'iterations' oder 'quantization_error' sein
// Value: Anzahl der Iterationen oder maximaler Quantisierungsfehler
// Blending: Exponent, der auf die Mitgliedschaftswerte angewandt wird. Dieser Parameter ist optional. Voreingestellt ist zwei.
// Centers: resultierende Clusterzentren
// Memberships: resultierende Mitgliedschaftswerte der Vektoren (Zeilen) in Clustern (Spalten). Dieser Parameter ist optional.
//
// Description
// Diese Funktion führt Fuzzy-C-Means-Clustering durch. Zu jeder Zeile von 
// Samples werden die Mitgliedschaftswerte in allen Clusterzentren berechnet.
// Dann werden die Clusterzentren neu berechnet.
// 
// Der Prozess endet, wenn eine vorgegebene Anzahl von Iterationen 
// durchgeführt wurde oder der Quantisierungsfehler eine vorgegebene 
// Obergrenze nicht überschreitet.
//
// Wenn von Anfang an die Abbruchbedingung erfüllt ist, ist
// Centers == InitialCenters
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 5);
//  [Centers Memberships] = FuzzyCMeans(Samples, InitialCenters, 2, 'iterations', 10);
//  Centers
//  Memberships(1 : 5, :)
//  XieBeniIndex = GetXieBeniIndex(Samples, Centers, Memberships, 2)
//
// See also
//  SelectRandomly
//  FuzzyQuantizationError
//  GetFuzzyMemberships
//  GetXieBeniIndex
//
// Authors
//  Dr. Eng. (J) Harald Galda;
//
// Bibliography
//Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// start of coding after on empty line to mark the end of the head_comments section
// Diese Datei ist nur dazu da, dass XML-Dateien generiert werden.
endfunction
