function QuantizationError = FuzzyQuantizationError(Samples, Centers, Memberships, NormType, Blending)
// berechnet den Fuzzy-Quantisierungsfehler.
//
// Calling Sequence
//   [QuantizationError] = FuzzyQuantizationError(Samples, Centers, Memberships, NormType, Blending)
//
// Parameters
// Samples: Matrix, die Beispielvektoren als Zeilen enthält
// Centers: Matrix, die Clusterzentren als Zeilen enthält
// Memberships: Mitgliedschaftswerte der Vektoren (Zeilen) in Clustern (Spalten)
// NormType: Norm der Vektoren, ist Skalar größer als null, kann %inf sein
// Blending: Exponent, der auf die Mitgliedschaftswerte angewandt wird. Dieser Parameter ist optional. Voreingestellt ist zwei.
// QuantizationError: Mitgliedschaftswerte der Vektoren (Zeilen) in Clustern (Spalten)
//
// Description
// Diese Funktion berechnet den Fuzzy-Quantisierungsfehler.
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 5);
//  [Centers Memberships] = FuzzyCMeans(Samples, InitialCenters, 2, 'iterations', 10);
//  QuantizationError = FuzzyQuantizationError(Samples, Centers, Memberships, 2)
//
// See also
//  SelectRandomly
//  GetFuzzyMemberships
//  FuzzyCMeans
//  GetXieBeniIndex
//
// Authors
//  Dr. Eng. (J) Harald Galda;
//
// Bibliography
// Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// start of coding after on empty line to mark the end of the head_comments section
// Diese Datei ist nur dafür da, dass XML-Dateien generiert werden.
endfunction
