function QuantizationError = FuzzyQuantizationError(Samples, Centers, Memberships, NormType, Blending)
// calculates the fuzzy quantization error.
//
// Calling Sequence
//   [QuantizationError] = FuzzyQuantizationError(Samples, Centers, Memberships, NormType, Blending)
//
// Parameters
// Samples: matrix, contains sample vectors as rows
// Centers: matrix, contains cluster centers as rows
// Memberships: membership values of the samples (rows) in the clusters (columns)
// NormType: norm of vectors, must be a scalar greater than zeros, can be %inf
// Blending: exponent applied to memberships. This parameter is optional. The default value is two.
// QuantizationError: the resulting fuzzy quantization error
//
// Description
// This function calculates the fuzzy quantization error.
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 5);
//  [Centers Memberships] = FuzzyCMeans(Samples, InitialCenters, 2, 'iterations', 10);
//  QuantizationError = FuzzyQuantizationError(Samples, Centers, Memberships, 2)
//
// See also
//  SelectRandomly
//  GetFuzzyMemberships
//  FuzzyCMeans
//  GetXieBeniIndex
//
// Authors
//  Dr. Eng. (J) Harald Galda;
//
// Bibliography
// Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// start of coding after on empty line to mark the end of the head_comments section
// This file is for *xml file generation only.
endfunction
