function [Centers, Memberships] = FuzzyCMeans(Samples, InitialCenters, NormType, Criterion, Value, Blending)
// はc-meansクラスタリングを行う
//
// Calling Sequence
//   [Centers, Memberships] = FuzzyCMeans(Samples, InitialCenters, NormType, Criterion, Value, Blending)
//   [Centers, Memberships] = FuzzyCMeans(Samples, InitialCenters, NormType, Criterion, Value)
//   [Centers] = FuzzyCMeans(Samples, InitialCenters, NormType, Criterion, Value, Blending)
//   [Centers, Memberships] = FuzzyCMeans(Samples, InitialCenters, NormType, Criterion, Value)
//
// Parameters
// Samples:サンプルを含む行列で、サンプルは行である
// InitialCenters:最初のクラスタの中央点を含む行列で、中央点は行である
// NormType:ベクトルにおけるノルムで、ゼロを超える数で、無限（%inf）である可能性がある
// Criterion:終了の条件の名前で、可能のある価値は「iterations」（回数）又は「quantization_error」（ファジー量子化誤差）である
// Value:回数又は量子化におけるエラーの最大値である
// Blending:所属度に適用される条である。このパラメータはオプショナルで、設定される値は2つである。
// Centers:最終のクラスタの中央点である
// Memberships:所属度を含む行列で、行はベクトルに相当して、クラスタは列に相当する。このパラメータはオプショナルである。
//
// Description
// 本関数はファジーc-meansクラスタリングを行う。Samplesにおける行のクラスタにおける所属度
// は計算されて、クラスタの中央点は更新される。最大の回数又はファジー量子化誤差を達する
// とこの過程は終了する。 
//  
// 終了の条件は最初から満たされると、Centers == InitialCentersである。
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 5);
//  [Centers Memberships] = FuzzyCMeans(Samples, InitialCenters, 2, 'iterations', 10);
//  Centers
//  Memberships(1 : 5, :)
//  XieBeniIndex = GetXieBeniIndex(Samples, Centers, Memberships, 2)
//
// See also
//  SelectRandomly
//  FuzzyQuantizationError
//  GetFuzzyMemberships
//  GetXieBeniIndex
//
// Authors
//  画留田ハラルド;
//
// Bibliography
// Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// start of coding after on empty line to mark the end of the head_comments section
// This file is for *xml file generation only.
endfunction
