function QuantizationError = FuzzyQuantizationError(Samples, Centers, Memberships, NormType, Blending)
// はファジー量子化誤差を計算する
//
// Calling Sequence
//   [QuantizationError] = FuzzyQuantizationError(Samples, Centers, Memberships, NormType, Blending)
//
// Parameters
// Samples:サンプルを含む行列で、サンプルは行である
// Centers:中央点を含む行列で、中央点は行である
// Memberships:所属度を含む行列で、行はサンプルに相当して、列はクラスタに相当する
// NormType:ベクトルにおけるノルムで、ゼロを超える数で、無限（%inf）である可能性がある
// Blending:所属度に適用される条である。このパラメータはオプショナルで、設定される値は2つである。
// QuantizationError:ファジー量子化誤差である
//
// Description
// 本関数はファジー量子化誤差を計算する。
//
// Examples
//  global CLUSTER_PATH;
//  Source = read_csv(CLUSTER_PATH + 'demos\IrisData.csv', ascii(9));
//  Samples = strtod(Source(:, 1 : 4));
//  InitialCenters = SelectRandomly(Samples, 5);
//  [Centers Memberships] = FuzzyCMeans(Samples, InitialCenters, 2, 'iterations', 10);
//  QuantizationError = FuzzyQuantizationError(Samples, Centers, Memberships, 2)
//
// See also
//  SelectRandomly
//  GetFuzzyMemberships
//  FuzzyCMeans
//  GetXieBeniIndex
//
// Authors
//  画留田ハラルド;
//
// Bibliography
// Richard O. Duda, Peter E. Hart, David G. Stork, 'Pattern Classification', John Wiley & Sons Inc., New York, Chichester, Weinheim, Brisbane, Singapore, Toronto, Second Edition, 2001 

// start of coding after on empty line to mark the end of the head_comments section
// This file is for *xml file generation only.
endfunction
